==> openshift-model-monitoring-6.7.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/MetadataConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MetadataConfigBuilder extends MetadataConfigFluentImpl<MetadataConfigBuilder> implements VisitableBuilder<MetadataConfig,MetadataConfigBuilder>{
  public MetadataConfigBuilder() {
    this(false);
  }
  public MetadataConfigBuilder(Boolean validationEnabled) {
    this(new MetadataConfig(), validationEnabled);
  }
  public MetadataConfigBuilder(MetadataConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public MetadataConfigBuilder(MetadataConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MetadataConfig(), validationEnabled);
  }
  public MetadataConfigBuilder(MetadataConfigFluent<?> fluent,MetadataConfig instance) {
    this(fluent, instance, false);
  }
  public MetadataConfigBuilder(MetadataConfigFluent<?> fluent,MetadataConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withSend(instance.getSend());
      fluent.withSendInterval(instance.getSendInterval());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public MetadataConfigBuilder(MetadataConfig instance) {
    this(instance,false);
  }
  public MetadataConfigBuilder(MetadataConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withSend(instance.getSend());
      this.withSendInterval(instance.getSendInterval());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  MetadataConfigFluent<?> fluent;
  Boolean validationEnabled;
  public MetadataConfig build() {
    MetadataConfig buildable = new MetadataConfig(fluent.getSend(),fluent.getSendInterval());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-monitoring-6.8.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/MetadataConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MetadataConfigBuilder extends MetadataConfigFluent<MetadataConfigBuilder> implements VisitableBuilder<MetadataConfig,MetadataConfigBuilder>{
  public MetadataConfigBuilder() {
    this(false);
  }
  public MetadataConfigBuilder(Boolean validationEnabled) {
    this(new MetadataConfig(), validationEnabled);
  }
  public MetadataConfigBuilder(MetadataConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public MetadataConfigBuilder(MetadataConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MetadataConfig(), validationEnabled);
  }
  public MetadataConfigBuilder(MetadataConfigFluent<?> fluent,MetadataConfig instance) {
    this(fluent, instance, false);
  }
  public MetadataConfigBuilder(MetadataConfigFluent<?> fluent,MetadataConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new MetadataConfig());

    if (instance != null) {
      fluent.withSend(instance.getSend());
      fluent.withSendInterval(instance.getSendInterval());
      fluent.withSend(instance.getSend());
      fluent.withSendInterval(instance.getSendInterval());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public MetadataConfigBuilder(MetadataConfig instance) {
    this(instance,false);
  }
  public MetadataConfigBuilder(MetadataConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new MetadataConfig());

    if (instance != null) {
      this.withSend(instance.getSend());
      this.withSendInterval(instance.getSendInterval());
      this.withSend(instance.getSend());
      this.withSendInterval(instance.getSendInterval());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  MetadataConfigFluent<?> fluent;
  Boolean validationEnabled;
  public MetadataConfig build() {
    MetadataConfig buildable = new MetadataConfig(fluent.getSend(),fluent.getSendInterval());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
